FlyColor class

Main entry point for context-aware color access

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) FlyColorScheme
Get context-aware color scheme from BuildContext

Constants

amber → const Color
amber1 → const Color
amber1Dark → const Color
amber2 → const Color
amber2Dark → const Color
amber3 → const Color
amber3Dark → const Color
amber4 → const Color
amber4Dark → const Color
amber5 → const Color
amber5Dark → const Color
amber6 → const Color
amber6Dark → const Color
amber7 → const Color
amber7Dark → const Color
amber8 → const Color
amber8Dark → const Color
amber9 → const Color
amber9Dark → const Color
amber10 → const Color
amber10Dark → const Color
amber11 → const Color
amber11Dark → const Color
amber12 → const Color
amber12Dark → const Color
amberContrast → const Color
amberContrastDark → const Color
amberSurface → const Color
amberSurfaceDark → const Color
blue → const Color
blue1 → const Color
blue1Dark → const Color
blue2 → const Color
blue2Dark → const Color
blue3 → const Color
blue3Dark → const Color
blue4 → const Color
blue4Dark → const Color
blue5 → const Color
blue5Dark → const Color
blue6 → const Color
blue6Dark → const Color
blue7 → const Color
blue7Dark → const Color
blue8 → const Color
blue8Dark → const Color
blue9 → const Color
blue9Dark → const Color
blue10 → const Color
blue10Dark → const Color
blue11 → const Color
blue11Dark → const Color
blue12 → const Color
blue12Dark → const Color
blueContrast → const Color
blueContrastDark → const Color
blueSurface → const Color
blueSurfaceDark → const Color
bronze → const Color
bronze1 → const Color
bronze1Dark → const Color
bronze2 → const Color
bronze2Dark → const Color
bronze3 → const Color
bronze3Dark → const Color
bronze4 → const Color
bronze4Dark → const Color
bronze5 → const Color
bronze5Dark → const Color
bronze6 → const Color
bronze6Dark → const Color
bronze7 → const Color
bronze7Dark → const Color
bronze8 → const Color
bronze8Dark → const Color
bronze9 → const Color
bronze9Dark → const Color
bronze10 → const Color
bronze10Dark → const Color
bronze11 → const Color
bronze11Dark → const Color
bronze12 → const Color
bronze12Dark → const Color
bronzeContrast → const Color
bronzeContrastDark → const Color
bronzeSurface → const Color
bronzeSurfaceDark → const Color
brown → const Color
brown1 → const Color
brown1Dark → const Color
brown2 → const Color
brown2Dark → const Color
brown3 → const Color
brown3Dark → const Color
brown4 → const Color
brown4Dark → const Color
brown5 → const Color
brown5Dark → const Color
brown6 → const Color
brown6Dark → const Color
brown7 → const Color
brown7Dark → const Color
brown8 → const Color
brown8Dark → const Color
brown9 → const Color
brown9Dark → const Color
brown10 → const Color
brown10Dark → const Color
brown11 → const Color
brown11Dark → const Color
brown12 → const Color
brown12Dark → const Color
brownContrast → const Color
brownContrastDark → const Color
brownSurface → const Color
brownSurfaceDark → const Color
crimson → const Color
crimson1 → const Color
crimson1Dark → const Color
crimson2 → const Color
crimson2Dark → const Color
crimson3 → const Color
crimson3Dark → const Color
crimson4 → const Color
crimson4Dark → const Color
crimson5 → const Color
crimson5Dark → const Color
crimson6 → const Color
crimson6Dark → const Color
crimson7 → const Color
crimson7Dark → const Color
crimson8 → const Color
crimson8Dark → const Color
crimson9 → const Color
crimson9Dark → const Color
crimson10 → const Color
crimson10Dark → const Color
crimson11 → const Color
crimson11Dark → const Color
crimson12 → const Color
crimson12Dark → const Color
crimsonContrast → const Color
crimsonContrastDark → const Color
crimsonSurface → const Color
crimsonSurfaceDark → const Color
cyan → const Color
cyan1 → const Color
cyan1Dark → const Color
cyan2 → const Color
cyan2Dark → const Color
cyan3 → const Color
cyan3Dark → const Color
cyan4 → const Color
cyan4Dark → const Color
cyan5 → const Color
cyan5Dark → const Color
cyan6 → const Color
cyan6Dark → const Color
cyan7 → const Color
cyan7Dark → const Color
cyan8 → const Color
cyan8Dark → const Color
cyan9 → const Color
cyan9Dark → const Color
cyan10 → const Color
cyan10Dark → const Color
cyan11 → const Color
cyan11Dark → const Color
cyan12 → const Color
cyan12Dark → const Color
cyanContrast → const Color
cyanContrastDark → const Color
cyanSurface → const Color
cyanSurfaceDark → const Color
gold → const Color
gold1 → const Color
gold1Dark → const Color
gold2 → const Color
gold2Dark → const Color
gold3 → const Color
gold3Dark → const Color
gold4 → const Color
gold4Dark → const Color
gold5 → const Color
gold5Dark → const Color
gold6 → const Color
gold6Dark → const Color
gold7 → const Color
gold7Dark → const Color
gold8 → const Color
gold8Dark → const Color
gold9 → const Color
gold9Dark → const Color
gold10 → const Color
gold10Dark → const Color
gold11 → const Color
gold11Dark → const Color
gold12 → const Color
gold12Dark → const Color
goldContrast → const Color
goldContrastDark → const Color
goldSurface → const Color
goldSurfaceDark → const Color
grass → const Color
grass1 → const Color
grass1Dark → const Color
grass2 → const Color
grass2Dark → const Color
grass3 → const Color
grass3Dark → const Color
grass4 → const Color
grass4Dark → const Color
grass5 → const Color
grass5Dark → const Color
grass6 → const Color
grass6Dark → const Color
grass7 → const Color
grass7Dark → const Color
grass8 → const Color
grass8Dark → const Color
grass9 → const Color
grass9Dark → const Color
grass10 → const Color
grass10Dark → const Color
grass11 → const Color
grass11Dark → const Color
grass12 → const Color
grass12Dark → const Color
grassContrast → const Color
grassContrastDark → const Color
grassSurface → const Color
grassSurfaceDark → const Color
gray → const Color
Convenience getters for step 9 (seed/base color) Step 9 is the same for light and dark modes
gray1 → const Color
Light mode colors (default)
gray1Dark → const Color
Dark mode colors (suffixed with Dark)
gray2 → const Color
gray2Dark → const Color
gray3 → const Color
gray3Dark → const Color
gray4 → const Color
gray4Dark → const Color
gray5 → const Color
gray5Dark → const Color
gray6 → const Color
gray6Dark → const Color
gray7 → const Color
gray7Dark → const Color
gray8 → const Color
gray8Dark → const Color
gray9 → const Color
gray9Dark → const Color
gray10 → const Color
gray10Dark → const Color
gray11 → const Color
gray11Dark → const Color
gray12 → const Color
gray12Dark → const Color
grayContrast → const Color
grayContrastDark → const Color
graySurface → const Color
graySurfaceDark → const Color
green → const Color
green1 → const Color
green1Dark → const Color
green2 → const Color
green2Dark → const Color
green3 → const Color
green3Dark → const Color
green4 → const Color
green4Dark → const Color
green5 → const Color
green5Dark → const Color
green6 → const Color
green6Dark → const Color
green7 → const Color
green7Dark → const Color
green8 → const Color
green8Dark → const Color
green9 → const Color
green9Dark → const Color
green10 → const Color
green10Dark → const Color
green11 → const Color
green11Dark → const Color
green12 → const Color
green12Dark → const Color
greenContrast → const Color
greenContrastDark → const Color
greenSurface → const Color
greenSurfaceDark → const Color
indigo → const Color
indigo1 → const Color
indigo1Dark → const Color
indigo2 → const Color
indigo2Dark → const Color
indigo3 → const Color
indigo3Dark → const Color
indigo4 → const Color
indigo4Dark → const Color
indigo5 → const Color
indigo5Dark → const Color
indigo6 → const Color
indigo6Dark → const Color
indigo7 → const Color
indigo7Dark → const Color
indigo8 → const Color
indigo8Dark → const Color
indigo9 → const Color
indigo9Dark → const Color
indigo10 → const Color
indigo10Dark → const Color
indigo11 → const Color
indigo11Dark → const Color
indigo12 → const Color
indigo12Dark → const Color
indigoContrast → const Color
indigoContrastDark → const Color
indigoSurface → const Color
indigoSurfaceDark → const Color
iris → const Color
iris1 → const Color
iris1Dark → const Color
iris2 → const Color
iris2Dark → const Color
iris3 → const Color
iris3Dark → const Color
iris4 → const Color
iris4Dark → const Color
iris5 → const Color
iris5Dark → const Color
iris6 → const Color
iris6Dark → const Color
iris7 → const Color
iris7Dark → const Color
iris8 → const Color
iris8Dark → const Color
iris9 → const Color
iris9Dark → const Color
iris10 → const Color
iris10Dark → const Color
iris11 → const Color
iris11Dark → const Color
iris12 → const Color
iris12Dark → const Color
irisContrast → const Color
irisContrastDark → const Color
irisSurface → const Color
irisSurfaceDark → const Color
jade → const Color
jade1 → const Color
jade1Dark → const Color
jade2 → const Color
jade2Dark → const Color
jade3 → const Color
jade3Dark → const Color
jade4 → const Color
jade4Dark → const Color
jade5 → const Color
jade5Dark → const Color
jade6 → const Color
jade6Dark → const Color
jade7 → const Color
jade7Dark → const Color
jade8 → const Color
jade8Dark → const Color
jade9 → const Color
jade9Dark → const Color
jade10 → const Color
jade10Dark → const Color
jade11 → const Color
jade11Dark → const Color
jade12 → const Color
jade12Dark → const Color
jadeContrast → const Color
jadeContrastDark → const Color
jadeSurface → const Color
jadeSurfaceDark → const Color
lime → const Color
lime1 → const Color
lime1Dark → const Color
lime2 → const Color
lime2Dark → const Color
lime3 → const Color
lime3Dark → const Color
lime4 → const Color
lime4Dark → const Color
lime5 → const Color
lime5Dark → const Color
lime6 → const Color
lime6Dark → const Color
lime7 → const Color
lime7Dark → const Color
lime8 → const Color
lime8Dark → const Color
lime9 → const Color
lime9Dark → const Color
lime10 → const Color
lime10Dark → const Color
lime11 → const Color
lime11Dark → const Color
lime12 → const Color
lime12Dark → const Color
limeContrast → const Color
limeContrastDark → const Color
limeSurface → const Color
limeSurfaceDark → const Color
mauve → const Color
mauve1 → const Color
mauve1Dark → const Color
mauve2 → const Color
mauve2Dark → const Color
mauve3 → const Color
mauve3Dark → const Color
mauve4 → const Color
mauve4Dark → const Color
mauve5 → const Color
mauve5Dark → const Color
mauve6 → const Color
mauve6Dark → const Color
mauve7 → const Color
mauve7Dark → const Color
mauve8 → const Color
mauve8Dark → const Color
mauve9 → const Color
mauve9Dark → const Color
mauve10 → const Color
mauve10Dark → const Color
mauve11 → const Color
mauve11Dark → const Color
mauve12 → const Color
mauve12Dark → const Color
mauveContrast → const Color
mauveContrastDark → const Color
mauveSurface → const Color
mauveSurfaceDark → const Color
mint → const Color
mint1 → const Color
mint1Dark → const Color
mint2 → const Color
mint2Dark → const Color
mint3 → const Color
mint3Dark → const Color
mint4 → const Color
mint4Dark → const Color
mint5 → const Color
mint5Dark → const Color
mint6 → const Color
mint6Dark → const Color
mint7 → const Color
mint7Dark → const Color
mint8 → const Color
mint8Dark → const Color
mint9 → const Color
mint9Dark → const Color
mint10 → const Color
mint10Dark → const Color
mint11 → const Color
mint11Dark → const Color
mint12 → const Color
mint12Dark → const Color
mintContrast → const Color
mintContrastDark → const Color
mintSurface → const Color
mintSurfaceDark → const Color
olive → const Color
olive1 → const Color
olive1Dark → const Color
olive2 → const Color
olive2Dark → const Color
olive3 → const Color
olive3Dark → const Color
olive4 → const Color
olive4Dark → const Color
olive5 → const Color
olive5Dark → const Color
olive6 → const Color
olive6Dark → const Color
olive7 → const Color
olive7Dark → const Color
olive8 → const Color
olive8Dark → const Color
olive9 → const Color
olive9Dark → const Color
olive10 → const Color
olive10Dark → const Color
olive11 → const Color
olive11Dark → const Color
olive12 → const Color
olive12Dark → const Color
oliveContrast → const Color
oliveContrastDark → const Color
oliveSurface → const Color
oliveSurfaceDark → const Color
orange → const Color
orange1 → const Color
orange1Dark → const Color
orange2 → const Color
orange2Dark → const Color
orange3 → const Color
orange3Dark → const Color
orange4 → const Color
orange4Dark → const Color
orange5 → const Color
orange5Dark → const Color
orange6 → const Color
orange6Dark → const Color
orange7 → const Color
orange7Dark → const Color
orange8 → const Color
orange8Dark → const Color
orange9 → const Color
orange9Dark → const Color
orange10 → const Color
orange10Dark → const Color
orange11 → const Color
orange11Dark → const Color
orange12 → const Color
orange12Dark → const Color
orangeContrast → const Color
orangeContrastDark → const Color
orangeSurface → const Color
orangeSurfaceDark → const Color
pink → const Color
pink1 → const Color
pink1Dark → const Color
pink2 → const Color
pink2Dark → const Color
pink3 → const Color
pink3Dark → const Color
pink4 → const Color
pink4Dark → const Color
pink5 → const Color
pink5Dark → const Color
pink6 → const Color
pink6Dark → const Color
pink7 → const Color
pink7Dark → const Color
pink8 → const Color
pink8Dark → const Color
pink9 → const Color
pink9Dark → const Color
pink10 → const Color
pink10Dark → const Color
pink11 → const Color
pink11Dark → const Color
pink12 → const Color
pink12Dark → const Color
pinkContrast → const Color
pinkContrastDark → const Color
pinkSurface → const Color
pinkSurfaceDark → const Color
plum → const Color
plum1 → const Color
plum1Dark → const Color
plum2 → const Color
plum2Dark → const Color
plum3 → const Color
plum3Dark → const Color
plum4 → const Color
plum4Dark → const Color
plum5 → const Color
plum5Dark → const Color
plum6 → const Color
plum6Dark → const Color
plum7 → const Color
plum7Dark → const Color
plum8 → const Color
plum8Dark → const Color
plum9 → const Color
plum9Dark → const Color
plum10 → const Color
plum10Dark → const Color
plum11 → const Color
plum11Dark → const Color
plum12 → const Color
plum12Dark → const Color
plumContrast → const Color
plumContrastDark → const Color
plumSurface → const Color
plumSurfaceDark → const Color
purple → const Color
purple1 → const Color
purple1Dark → const Color
purple2 → const Color
purple2Dark → const Color
purple3 → const Color
purple3Dark → const Color
purple4 → const Color
purple4Dark → const Color
purple5 → const Color
purple5Dark → const Color
purple6 → const Color
purple6Dark → const Color
purple7 → const Color
purple7Dark → const Color
purple8 → const Color
purple8Dark → const Color
purple9 → const Color
purple9Dark → const Color
purple10 → const Color
purple10Dark → const Color
purple11 → const Color
purple11Dark → const Color
purple12 → const Color
purple12Dark → const Color
purpleContrast → const Color
purpleContrastDark → const Color
purpleSurface → const Color
purpleSurfaceDark → const Color
red → const Color
red1 → const Color
red1Dark → const Color
red2 → const Color
red2Dark → const Color
red3 → const Color
red3Dark → const Color
red4 → const Color
red4Dark → const Color
red5 → const Color
red5Dark → const Color
red6 → const Color
red6Dark → const Color
red7 → const Color
red7Dark → const Color
red8 → const Color
red8Dark → const Color
red9 → const Color
red9Dark → const Color
red10 → const Color
red10Dark → const Color
red11 → const Color
red11Dark → const Color
red12 → const Color
red12Dark → const Color
redContrast → const Color
redContrastDark → const Color
redSurface → const Color
redSurfaceDark → const Color
ruby → const Color
ruby1 → const Color
ruby1Dark → const Color
ruby2 → const Color
ruby2Dark → const Color
ruby3 → const Color
ruby3Dark → const Color
ruby4 → const Color
ruby4Dark → const Color
ruby5 → const Color
ruby5Dark → const Color
ruby6 → const Color
ruby6Dark → const Color
ruby7 → const Color
ruby7Dark → const Color
ruby8 → const Color
ruby8Dark → const Color
ruby9 → const Color
ruby9Dark → const Color
ruby10 → const Color
ruby10Dark → const Color
ruby11 → const Color
ruby11Dark → const Color
ruby12 → const Color
ruby12Dark → const Color
rubyContrast → const Color
rubyContrastDark → const Color
rubySurface → const Color
rubySurfaceDark → const Color
sage → const Color
sage1 → const Color
sage1Dark → const Color
sage2 → const Color
sage2Dark → const Color
sage3 → const Color
sage3Dark → const Color
sage4 → const Color
sage4Dark → const Color
sage5 → const Color
sage5Dark → const Color
sage6 → const Color
sage6Dark → const Color
sage7 → const Color
sage7Dark → const Color
sage8 → const Color
sage8Dark → const Color
sage9 → const Color
sage9Dark → const Color
sage10 → const Color
sage10Dark → const Color
sage11 → const Color
sage11Dark → const Color
sage12 → const Color
sage12Dark → const Color
sageContrast → const Color
sageContrastDark → const Color
sageSurface → const Color
sageSurfaceDark → const Color
sand → const Color
sand1 → const Color
sand1Dark → const Color
sand2 → const Color
sand2Dark → const Color
sand3 → const Color
sand3Dark → const Color
sand4 → const Color
sand4Dark → const Color
sand5 → const Color
sand5Dark → const Color
sand6 → const Color
sand6Dark → const Color
sand7 → const Color
sand7Dark → const Color
sand8 → const Color
sand8Dark → const Color
sand9 → const Color
sand9Dark → const Color
sand10 → const Color
sand10Dark → const Color
sand11 → const Color
sand11Dark → const Color
sand12 → const Color
sand12Dark → const Color
sandContrast → const Color
sandContrastDark → const Color
sandSurface → const Color
sandSurfaceDark → const Color
sky → const Color
sky1 → const Color
sky1Dark → const Color
sky2 → const Color
sky2Dark → const Color
sky3 → const Color
sky3Dark → const Color
sky4 → const Color
sky4Dark → const Color
sky5 → const Color
sky5Dark → const Color
sky6 → const Color
sky6Dark → const Color
sky7 → const Color
sky7Dark → const Color
sky8 → const Color
sky8Dark → const Color
sky9 → const Color
sky9Dark → const Color
sky10 → const Color
sky10Dark → const Color
sky11 → const Color
sky11Dark → const Color
sky12 → const Color
sky12Dark → const Color
skyContrast → const Color
skyContrastDark → const Color
skySurface → const Color
skySurfaceDark → const Color
slate → const Color
slate1 → const Color
slate1Dark → const Color
slate2 → const Color
slate2Dark → const Color
slate3 → const Color
slate3Dark → const Color
slate4 → const Color
slate4Dark → const Color
slate5 → const Color
slate5Dark → const Color
slate6 → const Color
slate6Dark → const Color
slate7 → const Color
slate7Dark → const Color
slate8 → const Color
slate8Dark → const Color
slate9 → const Color
slate9Dark → const Color
slate10 → const Color
slate10Dark → const Color
slate11 → const Color
slate11Dark → const Color
slate12 → const Color
slate12Dark → const Color
slateContrast → const Color
slateContrastDark → const Color
slateSurface → const Color
slateSurfaceDark → const Color
teal → const Color
teal1 → const Color
teal1Dark → const Color
teal2 → const Color
teal2Dark → const Color
teal3 → const Color
teal3Dark → const Color
teal4 → const Color
teal4Dark → const Color
teal5 → const Color
teal5Dark → const Color
teal6 → const Color
teal6Dark → const Color
teal7 → const Color
teal7Dark → const Color
teal8 → const Color
teal8Dark → const Color
teal9 → const Color
teal9Dark → const Color
teal10 → const Color
teal10Dark → const Color
teal11 → const Color
teal11Dark → const Color
teal12 → const Color
teal12Dark → const Color
tealContrast → const Color
tealContrastDark → const Color
tealSurface → const Color
tealSurfaceDark → const Color
tomato → const Color
tomato1 → const Color
tomato1Dark → const Color
tomato2 → const Color
tomato2Dark → const Color
tomato3 → const Color
tomato3Dark → const Color
tomato4 → const Color
tomato4Dark → const Color
tomato5 → const Color
tomato5Dark → const Color
tomato6 → const Color
tomato6Dark → const Color
tomato7 → const Color
tomato7Dark → const Color
tomato8 → const Color
tomato8Dark → const Color
tomato9 → const Color
tomato9Dark → const Color
tomato10 → const Color
tomato10Dark → const Color
tomato11 → const Color
tomato11Dark → const Color
tomato12 → const Color
tomato12Dark → const Color
tomatoContrast → const Color
tomatoContrastDark → const Color
tomatoSurface → const Color
tomatoSurfaceDark → const Color
violet → const Color
violet1 → const Color
violet1Dark → const Color
violet2 → const Color
violet2Dark → const Color
violet3 → const Color
violet3Dark → const Color
violet4 → const Color
violet4Dark → const Color
violet5 → const Color
violet5Dark → const Color
violet6 → const Color
violet6Dark → const Color
violet7 → const Color
violet7Dark → const Color
violet8 → const Color
violet8Dark → const Color
violet9 → const Color
violet9Dark → const Color
violet10 → const Color
violet10Dark → const Color
violet11 → const Color
violet11Dark → const Color
violet12 → const Color
violet12Dark → const Color
violetContrast → const Color
violetContrastDark → const Color
violetSurface → const Color
violetSurfaceDark → const Color
yellow → const Color
yellow1 → const Color
yellow1Dark → const Color
yellow2 → const Color
yellow2Dark → const Color
yellow3 → const Color
yellow3Dark → const Color
yellow4 → const Color
yellow4Dark → const Color
yellow5 → const Color
yellow5Dark → const Color
yellow6 → const Color
yellow6Dark → const Color
yellow7 → const Color
yellow7Dark → const Color
yellow8 → const Color
yellow8Dark → const Color
yellow9 → const Color
yellow9Dark → const Color
yellow10 → const Color
yellow10Dark → const Color
yellow11 → const Color
yellow11Dark → const Color
yellow12 → const Color
yellow12Dark → const Color
yellowContrast → const Color
yellowContrastDark → const Color
yellowSurface → const Color
yellowSurfaceDark → const Color